@@ -9,3 +9,9 @@ dissiCl <- c("dissimilarity", "dist")
            ),
          warn = c()
          )
+
+## Not exported, and only used because CRAN checks must be faster
+doExtras <- function() {
+    interactive() || nzchar(Sys.getenv("R_CLUSTER_CHECK_EXTRA")) ||
+        identical("true", unname(Sys.getenv("R_PKG_CHECKING_doExtras")))
+}
